Learn R Programming

changepointTests (version 0.1.7)

multiplierDNonSeqfun: Function to perform multiplier bootstrap for changepoint

Description

This function simulates a random sample of Gaussian multipliers null hypothesis of a Gaussian HMM and compute the Cramer-von Mises and Kolmogorov-Smirnov test statistics.

Usage

multiplierDNonSeqfun(MC, MC1, grad, s, n, d)

Value

cvm

simulated value of the Cramer-von Mises statistic

ks

simulated value of the Kolmogorov-Smirnov statistic

Arguments

MC

matrix needed for multipliers

MC1

matrices needed for multipliers

grad

gradient of the copula

s

sequence of normalized values in (0,1)

n

length of the series

d

number of variables

Author

Bouchra R Nasri and Bruno N Remillard, August 6, 2020

References

Nasri, B. R. Remillard, B., & Bahraoui, T. (2022).