This function simulates a random sample of Gaussian multipliers null hypothesis of a Gaussian HMM and compute the Cramer-von Mises and Kolmogorov-Smirnov test statistics.
multiplierDSeqfun(U, grad, n, d)simulated value of the Cramer-von Mises statistic
simulated value of the Kolmogorov-Smirnov statistic
matrix needed for multipliers
gradient of the copula
length of the series
number of variables.
Bouchra R Nasri and Bruno N Remillard, August 6, 2020
Nasri, B. R. Remillard, B., & Bahraoui, T. (2022).