This function compute the Cramer-von Mises and Kolmogorov-Smirnov test statistics based on the new sequential process of Bucher et al (2014), using multipliers and parallel computing. Two methods of bootstrapping are used: non-sequential (fastest) and sequential. Both methods yields basically the same P-valueas.
test.change.point.copula.BKRS(
x,
N = 1000,
n_cores = 2,
method = "nonseq",
est = FALSE
)Cramer-von Mises statistic
Kolmogorov-Smirnov statistic
Pvalue for the Cramer-von Mises statistic
Pvalue for theKolmogorov-Smirnov statistic
Estimated changepoint using the Cramer-von Mises statistic
Estimated changepoint using the Kolmogorov-Smirnov statistic
(n x d) matrix of data (observations or pseudo-observations, including residuals), d >=2
number of multipliers samples to compute the P-value
number of cores for parallel computing (default = 2)
'nonseq' (default) or 'seq'
if TRUE, tau is estimated (default = FALSE)
Bouchra R Nasri and Bruno N Remillard, August 6, 2020
Nasri, B. R. Remillard, B., & Bahraoui, T. (2022). Change-point problems for multivariate time series using pseudo-observations, J. Multivariate Anal., 187, 104857.
Bucher, A., Kojadinovic, I., Rohmer, T., & Segers, J. (2014). Detecting changes in cross-sectional dependence in multivariate time series, J. Multiv. Anal., 132, 111--128.
x<-matrix(rnorm(100),ncol=2)
out = test.change.point.copula.BKRS(x)
Run the code above in your browser using DataLab